@@ -1,5 +1,6 @@
 // Copyright (C) 2017 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:critical reason:data-parser
 
 #include "qbluetoothservicediscoveryagent.h"
 #include "qbluetoothservicediscoveryagent_p.h"
@@ -500,7 +501,7 @@ void QBluetoothServiceDiscoveryAgentPrivate::processFoundService(quint64 deviceA
 
     QBluetoothServiceInfo returnInfo(info);
     bool deviceFound;
-    for (const QBluetoothDeviceInfo &deviceInfo : qAsConst(discoveredDevices)) {
+    for (const QBluetoothDeviceInfo &deviceInfo : std::as_const(discoveredDevices)) {
         if (deviceInfo.address().toUInt64() == deviceAddress) {
             deviceFound = true;
             returnInfo.setDevice(deviceInfo);
